Usage
Bayesfit(data, model, inf.sigma = TRUE, inc.nd = FALSE, sigma = 0.3, threshold = NULL, mumax.prior = "Uniform", mu.mean = NULL, mu.sd = NULL, tol = 0.1, prior.size = 100)
Arguments
data
A datafile of the curve to be fitted. This should consist of two columns, the first for time and second for logc.
The bacterial concentration should be given in log_10 cfu and there should be at least 2 data points (the first of which
may be undetected). Undetected y values should be represented by "NA".
model
The growth model to be used. This should be one of "linear", "logistic", "Bar3par", "Bar4par" and "Bar6par".
inf.sigma
(TRUE/FALSE) Choose whether or not to infer the noise level, sigma, as part of the analysis. If FALSE, sigma should be
specified (or the default value of sigma, 0.3, will be used).
inc.nd
Choose whether or not to include undetected points as part of the analysis. If TRUE, threshold should be specified.
sigma
The choice of noise level, sigma, in log_10 cfu if it is not inferred as part of the analysis. Default is 0.3.
threshold
Threshold in log_10 cfu below which values are considered as undetected.
mumax.prior
The type of prior to use for mu_max. This should be one of "Uniform", "Gaussian" or "Cauchy" (or the default "Uniform"
will be used). If "Gaussian" or "Cauchy" are specified, mu.mean and mu.sd should be given.
mu.mean
The mean to be used when using a Gaussian or Cauchy prior.
mu.sd
The standard deviation to be used when using a Gaussian or Cauchy prior.
tol
The termination tolerance for the nested sampling
prior.size
The number of prior samples to use for nested sampling